@@ -134,12 +134,30 @@ void AssetParameterModel::prepareKeyframes()
     if (m_keyframes) return;
     int ix = 0;
     for (const auto &name : m_rows) {
-        if (m_params[name].type == ParamType::KeyframeParam || m_params[name].type == ParamType::AnimatedRect ||
-            m_params[name].type == ParamType::Roto_spline) {
+        if (m_params.at(name).type == ParamType::KeyframeParam || m_params.at(name).type == ParamType::AnimatedRect ||
+            m_params.at(name).type == ParamType::Roto_spline) {
             addKeyframeParam(index(ix, 0));
         }
         ix++;
     }
+    if (m_keyframes) {
+        // Make sure we have keyframes at same position for all parameters
+        m_keyframes->checkConsistency();
+    }
+}
+
+QStringList AssetParameterModel::getKeyframableParameters() const
+{
+    QStringList paramNames;
+    int ix = 0;
+    for (const auto &name : m_rows) {
+        if (m_params.at(name).type == ParamType::KeyframeParam || m_params.at(name).type == ParamType::AnimatedRect) {
+            //addKeyframeParam(index(ix, 0));
+            paramNames << name;
+        }
+        ix++;
+    }
+    return paramNames;
 }
 
 void AssetParameterModel::setParameter(const QString &name, int value, bool update)
@@ -520,6 +538,7 @@ QVariant AssetParameterModel::parseAttribute(const ObjectId &owner, const QStrin
             if (ok) {
                 return res;
             }
+            return defaultValue;
         } else if (type == ParamType::Bezier_spline) {
             QLocale locale;
             if (locale.decimalPoint() != QLocale::c().decimalPoint()) {
