@@ -14,6 +14,7 @@ the Free Software Foundation, either version 3 of the License, or
 #include "definitions.h"
 #include "kdenlivecore_export.h"
 #include "undohelper.hpp"
+#include <QMutex>
 #include <QObject>
 #include <QTabWidget>
 #include <QUrl>
@@ -217,6 +218,8 @@ private:
     std::unique_ptr<MediaCapture> m_capture;
     QUrl m_mediaCaptureFile;
 
+    QMutex m_thumbProfileMutex;
+
 public slots:
     void triggerAction(const QString &name);
     /** @brief display a user info/warning message in the project bin */
