@@ -22,8 +22,8 @@
 
 #include "definitions.h"
 
-#include <QUndoCommand>
 #include <QPoint>
+#include <QUndoCommand>
 
 class ProjectList;
 class ProjectClip;
@@ -31,9 +31,10 @@ class ProjectClip;
 class AddClipCutCommand : public QUndoCommand
 {
 public:
-    AddClipCutCommand(ProjectList *list, const QString &id, int in, int out, const QString &desc, bool newItem, bool remove, QUndoCommand *parent = nullptr);
-    void undo() Q_DECL_OVERRIDE;
-    void redo() Q_DECL_OVERRIDE;
+    AddClipCutCommand(ProjectList *list, QString id, int in, int out, QString desc, bool newItem, bool remove, QUndoCommand *parent = nullptr);
+    void undo() override;
+    void redo() override;
+
 private:
     ProjectList *m_list;
     QString m_id;
@@ -47,9 +48,10 @@ private:
 class AddFolderCommand : public QUndoCommand
 {
 public:
-    AddFolderCommand(ProjectList *view, const QString &folderName, const QString &clipId, bool doIt, QUndoCommand *parent = nullptr);
-    void undo() Q_DECL_OVERRIDE;
-    void redo() Q_DECL_OVERRIDE;
+    AddFolderCommand(ProjectList *view, QString folderName, QString clipId, bool doIt, QUndoCommand *parent = nullptr);
+    void undo() override;
+    void redo() override;
+
 private:
     ProjectList *m_view;
     QString m_name;
@@ -60,9 +62,11 @@ private:
 class EditClipCutCommand : public QUndoCommand
 {
 public:
-    EditClipCutCommand(ProjectList *list, const QString &id, const QPoint &oldZone, const QPoint &newZone, const QString &oldComment, const QString &newComment, bool doIt, QUndoCommand *parent = nullptr);
-    void undo() Q_DECL_OVERRIDE;
-    void redo() Q_DECL_OVERRIDE;
+    EditClipCutCommand(ProjectList *list, QString id, const QPoint &oldZone, const QPoint &newZone, QString oldComment, QString newComment, bool doIt,
+                       QUndoCommand *parent = nullptr);
+    void undo() override;
+    void redo() override;
+
 private:
     ProjectList *m_list;
     QString m_id;
@@ -76,9 +80,10 @@ private:
 class EditFolderCommand : public QUndoCommand
 {
 public:
-    EditFolderCommand(ProjectList *view, const QString &newfolderName, const QString &oldfolderName, const QString &clipId, bool doIt, QUndoCommand *parent = nullptr);
-    void undo() Q_DECL_OVERRIDE;
-    void redo() Q_DECL_OVERRIDE;
+    EditFolderCommand(ProjectList *view, QString newfolderName, QString oldfolderName, QString clipId, bool doIt, QUndoCommand *parent = nullptr);
+    void undo() override;
+    void redo() override;
+
 private:
     ProjectList *m_view;
     QString m_name;
@@ -87,17 +92,4 @@ private:
     bool m_doIt;
 };
 
-class AddMarkerCommand : public QUndoCommand
-{
-public:
-    AddMarkerCommand(ProjectClip *clip, QList<CommentedTime> &oldMarkers, QList<CommentedTime> &newMarkers, QUndoCommand *parent = nullptr);
-    void undo() Q_DECL_OVERRIDE;
-    void redo() Q_DECL_OVERRIDE;
-private:
-    ProjectClip *m_clip;
-    QList<CommentedTime> m_oldMarkers;
-    QList<CommentedTime> m_newMarkers;
-};
-
 #endif
-
