@@ -11,24 +11,30 @@ the Free Software Foundation, either version 3 of the License, or
 #ifndef PROJECTMANAGER_H
 #define PROJECTMANAGER_H
 
-#include <QObject>
-#include <QUrl>
-#include <QTimer>
-#include <QTime>
-#include <QDir>
-#include <KRecentFilesAction>
 #include "kdenlivecore_export.h"
+#include <KRecentFilesAction>
+#include <QDir>
+#include <QObject>
+#include <QTime>
+#include <QTimer>
+#include <QUrl>
 
-#include "timeline/timeline.h"
+#include "timeline2/model/timelineitemmodel.hpp"
+
+#include <memory>
+#include <unordered_map>
+#include <unordered_set>
 
-class Project;
-class KdenliveDoc;
-class NotesPlugin;
-class QAction;
-class QUrl;
-class QProgressDialog;
 class KAutoSaveFile;
 class KJob;
+class KdenliveDoc;
+class MarkerListModel;
+class NotesPlugin;
+class Project;
+class QAction;
+class QProgressDialog;
+class QUrl;
+class DocUndoStack;
 
 /**
  * @class ProjectManager
@@ -42,11 +48,12 @@ class /*KDENLIVECORE_EXPORT*/ ProjectManager : public QObject
 public:
     /** @brief Sets up actions to interact for project interaction (undo, redo, open, save, ...) and creates an empty project. */
     explicit ProjectManager(QObject *parent = nullptr);
-    virtual ~ProjectManager();
+    ~ProjectManager() override;
 
-    /** @brief Returns a pointer to the currently opened project. A project should always be open. */
-    KdenliveDoc *current();
-    Timeline *currentTimeline();
+    /** @brief Returns a pointer to the currently opened project. A project should always be open.
+        The method is virtual to allow mocking
+     */
+    virtual KdenliveDoc *current();
 
     /** @brief Store command line args for later opening. */
     void init(const QUrl &projectUrl, const QString &clipList);
@@ -56,8 +63,6 @@ public:
     void prepareSave();
     /** @brief Disable all bin effects in current project */
     void disableBinEffects(bool disable);
-    /** @brief Returns true if there is a selected item in timeline */
-    bool hasSelection() const;
     /** @brief Returns current project's xml scene */
     QString projectSceneList(const QString &outputFolder);
     /** @brief returns a default hd profile depending on timezone*/
@@ -65,9 +70,27 @@ public:
     void saveZone(const QStringList &info, const QDir &dir);
     /** @brief Move project data files to new url */
     void moveProjectData(const QString &src, const QString &dest);
+    /** @brief Retrieve current project's notes */
+    QString documentNotes() const;
+
+    /** @brief Retrieve the current Guide Model
+        The method is virtual to allow mocking
+     */
+    virtual std::shared_ptr<MarkerListModel> getGuideModel();
+
+    /** @brief Return the current undo stack
+        The method is virtual to allow mocking
+    */
+    virtual std::shared_ptr<DocUndoStack> undoStack();
+
+    /** @brief This will create a backup file with fps appended to project name,
+     *  and save the project with an updated profile info, then reopen it.
+     */
+    void saveWithUpdatedProfile(const QString &updatedProfile);
 
 public slots:
-    void newFile(bool showProjectSettings = true, bool force = false);
+    void newFile(QString profileName, bool showProjectSettings = true);
+    void newFile(bool showProjectSettings = true);
     /** @brief Shows file open dialog. */
     void openFile();
     void openLastFile();
@@ -75,28 +98,26 @@ public slots:
     void slotLoadOnOpen();
 
     /** @brief Checks whether a URL is available to save to.
-    * @return Whether the file was saved. */
+     * @return Whether the file was saved. */
     bool saveFile();
 
     /** @brief Shows a save file dialog for saving the project.
-    * @return Whether the file was saved. */
+     * @return Whether the file was saved. */
     bool saveFileAs();
-    /** @brief Saves current timeline selection to an MLT playlist. */
-    void slotSaveSelection(const QString &path = QString());
 
     /** @brief Set properties to match outputFileName and save the document.
      * Creates an autosave version of the output file too, at
      * ~/.kde/data/stalefiles/kdenlive/ \n
      * that will be actually written in KdenliveDoc::slotAutoSave()
-    * @param outputFileName The URL to save to / The document's URL.
-    * @return Whether we had success. */
+     * @param outputFileName The URL to save to / The document's URL.
+     * @return Whether we had success. */
     bool saveFileAs(const QString &outputFileName);
     /** @brief Close currently opened document. Returns false if something went wrong (cannot save modifications, ...). */
     bool closeCurrentDocument(bool saveChanges = true, bool quit = false);
 
     /** @brief Prepares opening @param url.
-    *
-    * Checks if already open and whether backup exists */
+     *
+     * Checks if already open and whether backup exists */
     void openFile(const QUrl &url);
 
     /** @brief Start autosave timer */
@@ -105,6 +126,9 @@ public slots:
     /** @brief Update project and monitors profiles */
     void slotResetProfiles();
 
+    /** @brief Rebuild consumers after a property change */
+    void slotResetConsumers(bool fullReset);
+
     /** @brief Expand current timeline clip (recover clips and tracks from an MLT playlist) */
     void slotExpandClip();
 
@@ -114,9 +138,23 @@ public slots:
     /** @brief Un/Lock current timeline track */
     void slotSwitchTrackLock();
     void slotSwitchAllTrackLock();
+
+    /** @brief Make current timeline track active/inactive*/
+    void slotSwitchTrackActive();
+
     /** @brief Un/Set current track as target */
     void slotSwitchTrackTarget();
 
+    /** @brief Set the text for current project's notes */
+    void setDocumentNotes(const QString &notes);
+
+    /** @brief Project's duration changed, adjust monitor, etc. */
+    void adjustProjectDuration();
+    /** @brief Add an asset in timeline (effect, transition). */
+    void activateAsset(const QVariantMap &effectData);
+    /** @brief insert current timeline timecode in notes widget and focus widget to allow entering quick note */
+    void slotAddProjectNote();
+
 private slots:
     void slotRevert();
     /** @brief Open the project's backupdialog. */
@@ -129,18 +167,21 @@ private slots:
 
 signals:
     void docOpened(KdenliveDoc *document);
-//     void projectOpened(Project *project);
+    //     void projectOpened(Project *project);
+
+protected:
+    void updateTimeline(int pos = -1, int scrollPos = -1);
 
 private:
     /** @brief Checks that the Kdenlive MIME type is correctly installed.
-    * @param open If set to true, this will return the MIME type allowed for file opening (adds .tar.gz format)
-    * @return The MIME type */
+     * @param open If set to true, this will return the MIME type allowed for file opening (adds .tar.gz format)
+     * @return The MIME type */
     QString getMimeType(bool open = true);
     /** @brief checks if autoback files exists, recovers from it if user says yes, returns true if files were recovered. */
     bool checkForBackupFile(const QUrl &url, bool newFile = false);
 
-    KdenliveDoc *m_project;
-    Timeline *m_trackView;
+    KdenliveDoc *m_project{nullptr};
+    std::shared_ptr<TimelineItemModel> m_mainTimelineModel;
     QTime m_lastSave;
     QTimer m_autoSaveTimer;
     QUrl m_startUrl;
@@ -150,7 +191,7 @@ private:
     QAction *m_fileRevert;
     KRecentFilesAction *m_recentFilesAction;
     NotesPlugin *m_notesPlugin;
-    QProgressDialog *m_progressDialog;
+    QProgressDialog *m_progressDialog{nullptr};
     void saveRecentFiles();
 };
 
