@@ -186,6 +186,9 @@ bool TimelineFunctions::requestClipCut(const std::shared_ptr<TimelineItemModel>
             clipsToCut << cid;
         }
     }
+    if (clipsToCut.isEmpty()) {
+        return true;
+    }
     for (int cid : clipsToCut) {
         count++;
         int newId;
@@ -243,7 +246,7 @@ bool TimelineFunctions::requestSpacerEndOperation(const std::shared_ptr<Timeline
     // Start undoable command
     std::function<bool(void)> undo = []() { return true; };
     std::function<bool(void)> redo = []() { return true; };
-    int res = timeline->requestClipsGroup(clips, undo, redo);
+    int res = timeline->requestClipsGroup(clips, undo, redo, GroupType::Selection);
     bool final = false;
     if (res > -1) {
         if (clips.size() > 1) {
@@ -295,7 +298,6 @@ bool TimelineFunctions::insertZone(const std::shared_ptr<TimelineItemModel> &tim
     std::function<bool(void)> undo = []() { return true; };
     std::function<bool(void)> redo = []() { return true; };
     bool result = true;
-    int trackId = trackIds.takeFirst();
     if (overwrite) {
         // Cut all tracks
         auto it = timeline->m_allTracks.cbegin();
@@ -307,6 +309,7 @@ bool TimelineFunctions::insertZone(const std::shared_ptr<TimelineItemModel> &tim
             }
             result = result && TimelineFunctions::liftZone(timeline, target_track, QPoint(insertFrame, insertFrame + (zone.y() - zone.x())), undo, redo);
             if (!result) {
+                qDebug() << "// LIFTING ZONE FAILED\n";
                 break;
             }
             ++it;
@@ -330,14 +333,17 @@ bool TimelineFunctions::insertZone(const std::shared_ptr<TimelineItemModel> &tim
         result = result && TimelineFunctions::requestInsertSpace(timeline, QPoint(insertFrame, insertFrame + (zone.y() - zone.x())), undo, redo);
     }
     if (result) {
-        int newId = -1;
-        QString binClipId = QString("%1/%2/%3").arg(binId).arg(zone.x()).arg(zone.y() - 1);
-        result = timeline->requestClipInsertion(binClipId, trackId, insertFrame, newId, true, true, true, undo, redo);
+        if (!trackIds.isEmpty()) {
+            int newId = -1;
+            QString binClipId = QString("%1/%2/%3").arg(binId).arg(zone.x()).arg(zone.y() - 1);
+            result = timeline->requestClipInsertion(binClipId, trackIds.first(), insertFrame, newId, true, true, true, undo, redo);
+        }
         if (result) {
             pCore->pushUndo(undo, redo, overwrite ? i18n("Overwrite zone") : i18n("Insert zone"));
         }
     }
     if (!result) {
+        qDebug() << "// REQUESTING SPACE FAILED";
         undo();
     }
     return result;
@@ -375,15 +381,28 @@ bool TimelineFunctions::removeSpace(const std::shared_ptr<TimelineItemModel> &ti
 {
     Q_UNUSED(trackId)
 
-    std::unordered_set<int> clips = timeline->getItemsInRange(-1, zone.y() - 1, -1, true);
+    std::unordered_set<int> clips;
+    auto it = timeline->m_allTracks.cbegin();
+    while (it != timeline->m_allTracks.cend()) {
+        int target_track = (*it)->getId();
+        if (timeline->m_videoTarget == target_track || timeline->m_audioTarget == target_track ||
+            timeline->getTrackById_const(target_track)->shouldReceiveTimelineOp()) {
+            std::unordered_set<int> subs = timeline->getItemsInRange(target_track, zone.y() - 1, -1, true);
+            clips.insert(subs.begin(), subs.end());
+        }
+        ++it;
+    }
+
     bool result = false;
     if (!clips.empty()) {
         int clipId = *clips.begin();
         if (clips.size() > 1) {
+            int clipsGroup = timeline->m_groups->getRootId(clipId);
             int res = timeline->requestClipsGroup(clips, undo, redo);
             if (res > -1) {
                 result = timeline->requestGroupMove(clipId, res, 0, zone.x() - zone.y(), true, true, undo, redo);
-                if (result) {
+                if (result && res != clipsGroup) {
+                    // Only ungroup if a group was created
                     result = timeline->requestClipUngroup(clipId, undo, redo);
                 }
                 if (!result) {
@@ -399,12 +418,28 @@ bool TimelineFunctions::removeSpace(const std::shared_ptr<TimelineItemModel> &ti
     return result;
 }
 
-bool TimelineFunctions::requestInsertSpace(const std::shared_ptr<TimelineItemModel> &timeline, QPoint zone, Fun &undo, Fun &redo)
+bool TimelineFunctions::requestInsertSpace(const std::shared_ptr<TimelineItemModel> &timeline, QPoint zone, Fun &undo, Fun &redo, bool followTargets)
 {
     timeline->requestClearSelection();
     Fun local_undo = []() { return true; };
     Fun local_redo = []() { return true; };
-    std::unordered_set<int> items = timeline->getItemsInRange(-1, zone.x(), -1, true);
+    std::unordered_set<int> items;
+    if (!followTargets) {
+        // Select clips in all tracks
+        items = timeline->getItemsInRange(-1, zone.x(), -1, true);
+    } else {
+        // Select clips in target and active tracks only
+        auto it = timeline->m_allTracks.cbegin();
+        while (it != timeline->m_allTracks.cend()) {
+            int target_track = (*it)->getId();
+            if (timeline->m_videoTarget == target_track || timeline->m_audioTarget == target_track ||
+                timeline->getTrackById_const(target_track)->shouldReceiveTimelineOp()) {
+                std::unordered_set<int> subs = timeline->getItemsInRange(target_track, zone.x(), -1, true);
+                items.insert(subs.begin(), subs.end());
+            }
+            ++it;
+        }
+    }
     if (items.empty()) {
         return true;
     }
@@ -1045,25 +1080,24 @@ QPair<QList<int>, QList<int>> TimelineFunctions::getAVTracksIds(const std::share
 QString TimelineFunctions::copyClips(const std::shared_ptr<TimelineItemModel> &timeline, const std::unordered_set<int> &itemIds)
 {
     int clipId = *(itemIds.begin());
+    // We need to retrieve ALL the involved clips, ie those who are also grouped with the given clips
+    std::unordered_set<int> allIds;
+    for (const auto &itemId : itemIds) {
+        std::unordered_set<int> siblings = timeline->getGroupElements(itemId);
+        allIds.insert(siblings.begin(), siblings.end());
+    }
+
     timeline->requestClearSelection();
     // TODO better guess for master track
     int masterTid = timeline->getItemTrackId(clipId);
     bool audioCopy = timeline->isAudioTrack(masterTid);
     int masterTrack = timeline->getTrackPosition(masterTid);
-    std::unordered_set<int> groupRoots;
-    std::transform(itemIds.begin(), itemIds.end(), std::inserter(groupRoots, groupRoots.begin()), [&](int id) { return timeline->m_groups->getRootId(id); });
-
-    qDebug() << "==============\n GROUP ROOTS: ";
-    for (int gp : groupRoots) {
-        qDebug() << "GROUP: " << gp;
-    }
-    qDebug() << "\n=======";
     QDomDocument copiedItems;
     int offset = -1;
     QDomElement container = copiedItems.createElement(QStringLiteral("kdenlive-scene"));
     copiedItems.appendChild(container);
     QStringList binIds;
-    for (int id : itemIds) {
+    for (int id : allIds) {
         if (offset == -1 || timeline->getItemPosition(id) < offset) {
             offset = timeline->getItemPosition(id);
         }
@@ -1104,14 +1138,24 @@ QString TimelineFunctions::copyClips(const std::shared_ptr<TimelineItemModel> &t
     container.setAttribute(QStringLiteral("documentid"), pCore->currentDoc()->getDocumentProperty(QStringLiteral("documentid")));
     QDomElement grp = copiedItems.createElement(QStringLiteral("groups"));
     container.appendChild(grp);
+
+    std::unordered_set<int> groupRoots;
+    std::transform(allIds.begin(), allIds.end(), std::inserter(groupRoots, groupRoots.begin()), [&](int id) { return timeline->m_groups->getRootId(id); });
+
+    qDebug() << "==============\n GROUP ROOTS: ";
+    for (int gp : groupRoots) {
+        qDebug() << "GROUP: " << gp;
+    }
+    qDebug() << "\n=======";
     grp.appendChild(copiedItems.createTextNode(timeline->m_groups->toJson(groupRoots)));
-    // TODO: groups
+
     qDebug() << " / // / PASTED DOC: \n\n" << copiedItems.toString() << "\n\n------------";
     return copiedItems.toString();
 }
 
 bool TimelineFunctions::pasteClips(const std::shared_ptr<TimelineItemModel> &timeline, const QString &pasteString, int trackId, int position)
 {
+    timeline->requestClearSelection();
     QDomDocument copiedItems;
     copiedItems.setContent(pasteString);
     if (copiedItems.documentElement().tagName() == QLatin1String("kdenlive-scene")) {
@@ -1134,7 +1178,7 @@ bool TimelineFunctions::pasteClips(const std::shared_ptr<TimelineItemModel> &tim
     // List of all source video tracks
     QList<int> videoTracks;
     // List of all audio tracks with their corresponding video mirror
-    QMap<int, int> audioMirrors;
+    std::unordered_map<int, int> audioMirrors;
     // List of all source audio tracks that don't have video mirror
     QList<int> singleAudioTracks;
     for (int i = 0; i < clips.count(); i++) {
@@ -1153,7 +1197,7 @@ bool TimelineFunctions::pasteClips(const std::shared_ptr<TimelineItemModel> &tim
                 singleAudioTracks << trackPos;
                 continue;
             }
-            audioMirrors.insert(trackPos, videoMirror);
+            audioMirrors[trackPos] = videoMirror;
             if (videoTracks.contains(videoMirror)) {
                 continue;
             }
@@ -1178,9 +1222,9 @@ bool TimelineFunctions::pasteClips(const std::shared_ptr<TimelineItemModel> &tim
         videoTracks << atrackPos;
     }
     // Now we have a list of all source tracks, check that we have enough target tracks
-    qSort(videoTracks);
-    qSort(audioTracks);
-    qSort(singleAudioTracks);
+    std::sort(videoTracks.begin(), videoTracks.end());
+    std::sort(audioTracks.begin(), audioTracks.end());
+    std::sort(singleAudioTracks.begin(), singleAudioTracks.end());
     int requestedVideoTracks = videoTracks.isEmpty() ? 0 : videoTracks.last() - videoTracks.first() + 1;
     int requestedAudioTracks = audioTracks.isEmpty() ? 0 : audioTracks.last() - audioTracks.first() + 1;
     if (requestedVideoTracks > projectTracks.second.size() || requestedAudioTracks > projectTracks.first.size()) {
@@ -1213,19 +1257,17 @@ bool TimelineFunctions::pasteClips(const std::shared_ptr<TimelineItemModel> &tim
     qDebug() << "/// MASTER PASTE: " << masterIx;
     for (int tk : videoTracks) {
         tracksMap.insert(tk, projectTracks.second.at(masterIx + tk - masterSourceTrack));
-        qDebug() << "// TK MAP: " << tk << " => " << projectTracks.second.at(masterIx + tk - masterSourceTrack);
+        qDebug() << "// TK MAP: " << tk << " => " << tracksMap[tk];
     }
-    QMapIterator<int, int> it(audioMirrors);
-    while (it.hasNext()) {
-        it.next();
-        int videoIx = tracksMap.value(it.value());
+    for (const auto &mirror : audioMirrors) {
+        int videoIx = tracksMap.value(mirror.second);
         // qDebug()<<"// TK AUDIO MAP: "<<it.key()<<" => "<<videoIx<<" ; AUDIO MIRROR: "<<timeline->getMirrorAudioTrackId(videoIx);
-        tracksMap.insert(it.key(), timeline->getMirrorAudioTrackId(videoIx));
+        tracksMap.insert(mirror.first, timeline->getMirrorAudioTrackId(videoIx));
     }
     for (int i = 0; i < singleAudioTracks.size(); i++) {
         tracksMap.insert(singleAudioTracks.at(i), projectTracks.first.at(i));
     }
-    qDebug() << "++++++++++++++++++++++++++\n\n\n// AUDIO MIRRORS: " << audioMirrors << ", RESULT: " << tracksMap;
+    qDebug() << "++++++++++++++++++++++++++\n\n\n// TRACK MAP: " << tracksMap;
     if (!docId.isEmpty() && docId != pCore->currentDoc()->getDocumentProperty(QStringLiteral("documentid"))) {
         // paste from another document, import bin clips
         QString folderId = pCore->projectItemModel()->getFolderIdByName(i18n("Pasted clips"));
@@ -1328,6 +1370,15 @@ bool TimelineFunctions::pasteClips(const std::shared_ptr<TimelineItemModel> &tim
     const QString groupsData = copiedItems.documentElement().firstChildElement(QStringLiteral("groups")).text();
     // Rebuild groups
     timeline->m_groups->fromJsonWithOffset(groupsData, tracksMap, position - offset, undo, redo);
+    // unsure to clear selection in undo/redo too.
+    Fun unselect = [&]() {
+        qDebug() << "starting undo or redo. Selection " << timeline->m_currentSelection;
+        timeline->requestClearSelection();
+        qDebug() << "after Selection " << timeline->m_currentSelection;
+        return true;
+    };
+    PUSH_FRONT_LAMBDA(unselect, undo);
+    PUSH_FRONT_LAMBDA(unselect, redo);
     pCore->pushUndo(undo, redo, i18n("Paste clips"));
     return true;
 }
