@@ -31,6 +31,7 @@
 #include "kdenlivesettings.h"
 #include "macros.hpp"
 #include "trackmodel.hpp"
+#include "snapmodel.hpp"
 #include "transitions/transitionsrepository.hpp"
 #include <QDebug>
 #include <QFileInfo>
@@ -62,7 +63,7 @@ void TimelineItemModel::finishConstruct(const std::shared_ptr<TimelineItemModel>
 {
     ptr->weak_this_ = ptr;
     ptr->m_groups = std::make_unique<GroupsModel>(ptr);
-    guideModel->registerSnapModel(ptr->m_snaps);
+    guideModel->registerSnapModel(std::static_pointer_cast<SnapInterface>(ptr->m_snaps));
 }
 
 std::shared_ptr<TimelineItemModel> TimelineItemModel::construct(Mlt::Profile *profile, std::shared_ptr<MarkerListModel> guideModel,
@@ -116,7 +117,7 @@ QModelIndex TimelineItemModel::makeClipIndexFromID(int clipId) const
     int trackId = m_allClips.at(clipId)->getCurrentTrackId();
     if (trackId == -1) {
         // Clip is not inserted in a track
-        qDebug() << "/// WARNING; INVALID CLIP INDEX REQUESTED\n________________";
+        qDebug() << "/// WARNING; INVALID CLIP INDEX REQUESTED: "<<clipId<<"\n________________";
         return {};
     }
     int row = getTrackById_const(trackId)->getRowfromClip(clipId);
@@ -223,6 +224,7 @@ QHash<int, QByteArray> TimelineItemModel::roleNames() const
     roles[CanBeAudioRole] = "canBeAudio";
     roles[CanBeVideoRole] = "canBeVideo";
     roles[ReloadThumbRole] = "reloadThumb";
+    roles[PositionOffsetRole] = "positionOffset";
     roles[ThumbsFormatRole] = "thumbsFormat";
     roles[AudioRecordRole] = "audioRecord";
     roles[TrackActiveRole] = "trackActive";
@@ -332,6 +334,8 @@ QVariant TimelineItemModel::data(const QModelIndex &index, int role) const
             return clip->fadeOut();
         case ReloadThumbRole:
             return clip->forceThumbReload;
+        case PositionOffsetRole:
+            return clip->getOffset();
         case SpeedRole:
             return clip->getSpeed();
         case GrabbedRole:
