@@ -328,6 +328,12 @@ int TimelineController::insertNewComposition(int tid, int clipId, int offset, co
     int position = minimum;
     if (offset > clip_duration / 2) {
         position += offset;
+    } else {
+        // Check if we have a composition at beginning
+        std::unordered_set<int> existing = m_model->getTrackById_const(tid)->getCompositionsInRange(minimum, minimum + offset);
+        if (existing.size() > 0) {
+            position += offset;
+        }
     }
     position = qMin(minimum + clip_duration - 1, position);
     int duration = m_model->getTrackById_const(tid)->suggestCompositionLength(position);
@@ -498,9 +504,19 @@ void TimelineController::deleteTrack(int tid)
     QPointer<TrackDialog> d = new TrackDialog(m_model, tid, qApp->activeWindow(), true);
     if (d->exec() == QDialog::Accepted) {
         int selectedTrackIx = d->selectedTrackId();
+        if (m_activeTrack == selectedTrackIx) {
+            // Make sure we don't keep an index on a deleted track
+            m_activeTrack = -1;
+        }
+        if (m_model->m_audioTarget == selectedTrackIx) {
+            setAudioTarget(-1);
+        }
+        if (m_model->m_videoTarget == selectedTrackIx) {
+            setVideoTarget(-1);
+        }
         m_model->requestTrackDeletion(selectedTrackIx);
         m_model->buildTrackCompositing(true);
-        if (m_activeTrack == selectedTrackIx) {
+        if (m_activeTrack == -1) {
             setActiveTrack(m_model->getTrackIndexFromPosition(m_model->getTracksCount() - 1));
         }
     }
@@ -546,8 +562,21 @@ void TimelineController::unGroupSelection(int cid)
     }
 }
 
+bool TimelineController::dragOperationRunning()
+{
+    QVariant returnedValue;
+    QMetaObject::invokeMethod(m_root, "isDragging", Q_RETURN_ARG(QVariant, returnedValue));
+    return returnedValue.toBool();
+}
+
 void TimelineController::setInPoint()
 {
+    if (dragOperationRunning()) {
+        // Don't allow timeline operation while drag in progress
+        qDebug()<<"Cannot operate while dragging";
+        return;
+    }
+
     int cursorPos = timelinePosition();
     const auto selection = m_model->getCurrentSelection();
     if (!selection.empty()) {
@@ -569,6 +598,11 @@ int TimelineController::timelinePosition() const
 
 void TimelineController::setOutPoint()
 {
+    if (dragOperationRunning()) {
+        // Don't allow timeline operation while drag in progress
+        qDebug()<<"Cannot operate while dragging";
+        return;
+    }
     int cursorPos = timelinePosition();
     const auto selection = m_model->getCurrentSelection();
     if (!selection.empty()) {
@@ -583,13 +617,62 @@ void TimelineController::setOutPoint()
     }
 }
 
-void TimelineController::editMarker(const QString &cid, int frame)
+void TimelineController::editMarker(int cid, int position)
 {
-    std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(cid);
-    GenTime pos(frame, pCore->getCurrentFps());
+    Q_ASSERT(m_model->isClip(cid));
+    if (position < m_model->getClipPosition(cid) || position > (m_model->getClipPosition(cid) + m_model->getClipPlaytime(cid))) {
+        pCore->displayMessage(i18n("Cannot find clip to edit marker"), InformationMessage, 500);
+        return;
+    }
+    std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(getClipBinId(cid));
+    GenTime pos(position - m_model->getClipPosition(cid) + m_model->getClipIn(cid), pCore->getCurrentFps());
     clip->getMarkerModel()->editMarkerGui(pos, qApp->activeWindow(), false, clip.get());
 }
 
+void TimelineController::addMarker(int cid, int position)
+{
+    Q_ASSERT(m_model->isClip(cid));
+    if (position < m_model->getClipPosition(cid) || position > (m_model->getClipPosition(cid) + m_model->getClipPlaytime(cid))) {
+        pCore->displayMessage(i18n("Cannot find clip to add marker"), InformationMessage, 500);
+        return;
+    }
+    std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(getClipBinId(cid));
+    GenTime pos(position - m_model->getClipPosition(cid) + m_model->getClipIn(cid), pCore->getCurrentFps());
+    clip->getMarkerModel()->editMarkerGui(pos, qApp->activeWindow(), true, clip.get());
+}
+
+void TimelineController::addQuickMarker(int cid, int position)
+{
+    Q_ASSERT(m_model->isClip(cid));
+    if (position < m_model->getClipPosition(cid) || position > (m_model->getClipPosition(cid) + m_model->getClipPlaytime(cid))) {
+        pCore->displayMessage(i18n("Cannot find clip to add marker"), InformationMessage, 500);
+        return;
+    }
+    std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(getClipBinId(cid));
+    GenTime pos(position - m_model->getClipPosition(cid) + m_model->getClipIn(cid), pCore->getCurrentFps());
+    CommentedTime marker(pos, pCore->currentDoc()->timecode().getDisplayTimecode(pos, false), KdenliveSettings::default_marker_type());
+    clip->getMarkerModel()->addMarker(marker.time(), marker.comment(), marker.markerType());
+}
+
+void TimelineController::deleteMarker(int cid, int position)
+{
+    Q_ASSERT(m_model->isClip(cid));
+    if (position < m_model->getClipPosition(cid) || position > (m_model->getClipPosition(cid) + m_model->getClipPlaytime(cid))) {
+        pCore->displayMessage(i18n("Cannot find clip to remove marker"), InformationMessage, 500);
+        return;
+    }
+    std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(getClipBinId(cid));
+    GenTime pos(position - m_model->getClipPosition(cid) + m_model->getClipIn(cid), pCore->getCurrentFps());
+    clip->getMarkerModel()->removeMarker(pos);
+}
+
+void TimelineController::deleteAllMarkers(int cid)
+{
+    Q_ASSERT(m_model->isClip(cid));
+    std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(getClipBinId(cid));
+    clip->getMarkerModel()->removeAllMarkers();
+}
+
 void TimelineController::editGuide(int frame)
 {
     if (frame == -1) {
@@ -1389,6 +1472,55 @@ void TimelineController::extract(int clipId)
     TimelineFunctions::extractZone(m_model, QVector<int>() << track, zone, false);
 }
 
+bool TimelineController::insertClipZone(const QString &binId, int tid, int position)
+{
+    QStringList binIdData = binId.split(QLatin1Char('/'));
+    int in = 0;
+    int out = -1;
+    if (binIdData.size() >= 3) {
+        in = binIdData.at(1).toInt();
+        out = binIdData.at(2).toInt();
+    }
+
+    QString bid = binIdData.first();
+    // dropType indicates if we want a normal drop (disabled), audio only or video only drop
+    PlaylistState::ClipState dropType = PlaylistState::Disabled;
+    if (bid.startsWith(QLatin1Char('A'))) {
+        dropType = PlaylistState::AudioOnly;
+        bid = bid.remove(0, 1);
+    } else if (bid.startsWith(QLatin1Char('V'))) {
+        dropType = PlaylistState::VideoOnly;
+        bid = bid.remove(0, 1);
+    }
+    int aTrack = -1;
+    int vTrack = -1;
+    std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(bid);
+    if (out <= in) {
+        out = clip->frameDuration() - 1;
+    }
+    if (dropType == PlaylistState::VideoOnly) {
+        vTrack = tid;
+    } else if (dropType == PlaylistState::AudioOnly) {
+        aTrack = tid;
+    } else {
+        if (m_model->getTrackById_const(tid)->isAudioTrack()) {
+            aTrack = tid;
+            vTrack = clip->hasAudioAndVideo() ? m_model->getMirrorVideoTrackId(aTrack) : -1;
+        } else {
+            vTrack = tid;
+            aTrack = clip->hasAudioAndVideo() ? m_model->getMirrorAudioTrackId(vTrack) : -1;
+        }
+    }
+    QList<int> target_tracks;
+    if (vTrack > -1) {
+        target_tracks << vTrack;
+    }
+    if (aTrack > -1) {
+        target_tracks << aTrack;
+    }
+    return TimelineFunctions::insertZone(m_model, target_tracks, binId, position, QPoint(in, out), m_model->m_editMode == TimelineMode::OverwriteEdit);
+}
+
 int TimelineController::insertZone(const QString &binId, QPoint zone, bool overwrite)
 {
     std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(binId);
@@ -1400,7 +1532,7 @@ int TimelineController::insertZone(const QString &binId, QPoint zone, bool overw
     if (clip->hasVideo()) {
         vTrack = videoTarget();
     }
-    if (aTrack == -1 && vTrack == -1) {
+    /*if (aTrack == -1 && vTrack == -1) {
         // No target tracks defined, use active track
         if (m_model->getTrackById_const(m_activeTrack)->isAudioTrack()) {
             aTrack = m_activeTrack;
@@ -1409,7 +1541,7 @@ int TimelineController::insertZone(const QString &binId, QPoint zone, bool overw
             vTrack = m_activeTrack;
             aTrack = m_model->getMirrorAudioTrackId(vTrack);
         }
-    }
+    }*/
     int insertPoint;
     QPoint sourceZone;
     if (useRuler() && m_zone != QPoint()) {
@@ -1511,7 +1643,7 @@ void TimelineController::setAudioRef(int clipId)
     std::unique_ptr<AudioEnvelope> envelope(new AudioEnvelope(getClipBinId(clipId), clipId));
     m_audioCorrelator.reset(new AudioCorrelation(std::move(envelope)));
     connect(m_audioCorrelator.get(), &AudioCorrelation::gotAudioAlignData, [&](int cid, int shift) {
-        int pos = m_model->getClipPosition(m_audioRef) + shift + m_model->getClipIn(m_audioRef);
+        int pos = m_model->getClipPosition(m_audioRef) + shift - m_model->getClipIn(m_audioRef);
         bool result = m_model->requestClipMove(cid, m_model->getClipTrackId(cid), pos, true, true);
         if (!result) {
             pCore->displayMessage(i18n("Cannot move clip to frame %1.", (pos + shift)), InformationMessage, 500);
@@ -1547,7 +1679,7 @@ void TimelineController::alignAudio(int clipId)
         }
     }
     // Perform audio calculation
-    AudioEnvelope *envelope = new AudioEnvelope(getClipBinId(clipId), clipId, (size_t)m_model->getClipIn(clipId), (size_t)m_model->getClipPlaytime(clipId),
+    AudioEnvelope *envelope = new AudioEnvelope(otherBinId, clipId, (size_t)m_model->getClipIn(clipId), (size_t)m_model->getClipPlaytime(clipId),
                                                 (size_t)m_model->getClipPosition(clipId));
     m_audioCorrelator->addChild(envelope);
 }
@@ -1708,9 +1840,12 @@ void TimelineController::pasteEffects(int targetId)
     std::function<bool(void)> undo = []() { return true; };
     std::function<bool(void)> redo = []() { return true; };
     QDomElement effects = clips.at(0).firstChildElement(QStringLiteral("effects"));
+    effects.setAttribute(QStringLiteral("parentIn"), clips.at(0).toElement().attribute(QStringLiteral("in")));
     for (int i = 1; i < clips.size(); i++) {
-        QDomNodeList subs = clips.at(i).childNodes();
+        QDomElement subeffects = clips.at(i).firstChildElement(QStringLiteral("effects"));
+        QDomNodeList subs = subeffects.childNodes();
         for (int j = 0; j < subs.size(); j++) {
+            subs.at(j).toElement().setAttribute(QStringLiteral("parentIn"), clips.at(i).toElement().attribute(QStringLiteral("in")));
             effects.appendChild(subs.at(j));
         }
     }
@@ -1941,7 +2076,7 @@ bool TimelineController::endFakeMove(int clipId, int position, bool updateView,
             // There is a clip, cut
             res = res && TimelineFunctions::requestClipCut(m_model, startClipId, position, undo, redo);
         }
-        res = res && TimelineFunctions::requestInsertSpace(m_model, QPoint(position, position + duration), undo, redo);
+        res = res && TimelineFunctions::requestInsertSpace(m_model, QPoint(position, position + duration), undo, redo, false);
     }
     res = res && m_model->getTrackById(trackId)->requestClipInsertion(clipId, position, updateView, invalidateTimeline, undo, redo);
     if (res) {
@@ -2055,7 +2190,7 @@ bool TimelineController::endFakeGroupMove(int clipId, int groupId, int delta_tra
                 res = res && TimelineFunctions::requestClipCut(m_model, startClipId, target_position, undo, redo);
             }
         }
-        res = res && TimelineFunctions::requestInsertSpace(m_model, QPoint(min, max), undo, redo);
+        res = res && TimelineFunctions::requestInsertSpace(m_model, QPoint(min, max), undo, redo, false);
     }
     for (int item : sorted_clips) {
         if (m_model->isClip(item)) {
