@@ -228,7 +228,19 @@ public:
     Q_INVOKABLE void unGroupSelection(int cid = -1);
     /* @brief Ask for edit marker dialog
      */
-    Q_INVOKABLE void editMarker(const QString &cid, int frame);
+    Q_INVOKABLE void editMarker(int cid, int position);
+    /* @brief Ask for marker add dialog
+     */
+    Q_INVOKABLE void addMarker(int cid, int position);
+    /* @brief Ask for quick marker add (without dialog)
+     */
+    Q_INVOKABLE void addQuickMarker(int cid, int position);
+    /* @brief Ask for marker delete
+     */
+    Q_INVOKABLE void deleteMarker(int cid, int position);
+    /* @brief Ask for all markers delete
+     */
+    Q_INVOKABLE void deleteAllMarkers(int cid);
     /* @brief Ask for edit timeline guide dialog
      */
     Q_INVOKABLE void editGuide(int frame = -1);
@@ -409,6 +421,7 @@ public:
     /** @brief Insert clip monitor into timeline
      *  @returns the zone end position or -1 on fail
      */
+    Q_INVOKABLE bool insertClipZone(const QString &binId, int tid, int pos);
     int insertZone(const QString &binId, QPoint zone, bool overwrite);
     void updateClip(int clipId, const QVector<int> &roles);
     void showClipKeyframes(int clipId, bool value);
@@ -427,6 +440,8 @@ public:
     void grabCurrent();
     /** @brief Returns keys for all used thumbnails */
     QStringList getThumbKeys();
+    /** @brief Returns true if a drag operation is currently running in timeline */
+    bool dragOperationRunning();
 
 public slots:
     void resetView();
